@@ -9,6 +9,5 @@ class ColorValidator(_plotly_utils.basevalidators.ColorValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "plot"),
-            role=kwargs.pop("role", "style"),
-            **kwargs
+            **kwargs,
         )
