@@ -9,5 +9,5 @@ class LegendgroupValidator(_plotly_utils.basevalidators.StringValidator):
             plotly_name=plotly_name,
             parent_name=parent_name,
             edit_type=kwargs.pop("edit_type", "style"),
-            **kwargs
+            **kwargs,
         )
